@@ -4,7 +4,7 @@ use 5.014;
 
 use Data::Object 'Class', 'Doodle::Library';
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 has name => (
   is => 'ro',
@@ -81,6 +81,12 @@ method delete(Any %args) {
   return $command;
 }
 
+method unique() {
+  $self->data->{unique} = 1;
+
+  return $self;
+}
+
 1;
 
 =encoding utf8
@@ -164,3 +170,20 @@ Returns the associated Doodle object.
 =back
 
 =cut
+
+=head2 unique
+
+  unique() : Index
+
+Denotes that the index should be created and enforced as unique and returns
+itself.
+
+=over 4
+
+=item unique example
+
+  my $unique = $self->unique;
+
+=back
+
+=cut
