@@ -4,9 +4,8 @@ use 5.014;
 
 use Data::Object 'Role', 'Doodle::Library';
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
-# BUILD
 # METHODS
 
 method binary(Str $name, Any %args) {
@@ -233,6 +232,18 @@ method temporary() {
   return $self;
 }
 
+method if_exists() {
+  $self->data->{if_exists} = 1;
+
+  return $self;
+}
+
+method if_not_exists() {
+  $self->data->{if_not_exists} = 1;
+
+  return $self;
+}
+
 method text(Str $name, Any %args) {
   my $column = $self->column($name);
 
@@ -333,7 +344,7 @@ Doodle::Table::Helpers
 
 =head1 ABSTRACT
 
-Nam suscipit iaculis magna vitae faucibus.
+Doodle Table Helpers
 
 =cut
 
@@ -349,7 +360,7 @@ Nam suscipit iaculis magna vitae faucibus.
 
 =head1 DESCRIPTION
 
-Doodle Table Helpers
+Helpers for configuring Table classes.
 
 =cut
 
@@ -521,6 +532,40 @@ Registers a float column and returns the Command object set.
 
 =cut
 
+=head2 if_exists
+
+  if_exists() : Table
+
+Used with the C<delete> method to denote that the table should be deleted only
+if it already exists.
+
+=over 4
+
+=item if_exists example
+
+  $self->if_exists;
+
+=back
+
+=cut
+
+=head2 if_not_exists
+
+  if_not_exists() : Table
+
+Used with the C<create> method to denote that the table should be created only
+if it doesn't already exist.
+
+=over 4
+
+=item if_not_exists example
+
+  $self->if_not_exists;
+
+=back
+
+=cut
+
 =head2 increments_big
 
   increments_big(Str $name, Any %args) : Column
